@@ -123,7 +123,7 @@ SC_LTTNG_TRACEPOINT_ENUM(lttng_clone_option_flags,
 		lttng_kernel_static_type_enum(&__enum_lttng_clone_exit_signal_flags, \
 			lttng_kernel_static_type_integer(CLONE_EXIT_SIGNAL_FLAG_RESERVED_BITS, \
 				1, 0, __BYTE_ORDER, 16)),		\
-		false, false, false)
+		false, false)
 
 #define LTTNG_CLONE_FLAGS_OPTIONS					\
 	lttng_kernel_static_event_field("options",			\
@@ -131,7 +131,7 @@ SC_LTTNG_TRACEPOINT_ENUM(lttng_clone_option_flags,
 			lttng_kernel_static_type_integer(		\
 				sizeof(unsigned long) * CHAR_BIT - CLONE_EXIT_SIGNAL_FLAG_RESERVED_BITS, \
 				1, 0, __BYTE_ORDER, 16)),		\
-		false, false, false)
+		false, false)
 
 #if (__BYTE_ORDER == __LITTLE_ENDIAN)
 #define LTTNG_CLONE_FLAGS			\
@@ -479,25 +479,25 @@ SC_LTTNG_TRACEPOINT_EVENT_CODE(pselect6,
 static const struct lttng_kernel_event_field *lttng_pollfd_flag_fields[] = {
 	[ilog2(POLLIN)] = lttng_kernel_static_event_field("POLLIN",
 				lttng_kernel_static_type_integer(1, 1, 0, __LITTLE_ENDIAN, 10),
-				false, false, false),
+				false, false),
 	[ilog2(POLLPRI)] = lttng_kernel_static_event_field("POLLPRI",
 				lttng_kernel_static_type_integer(1, 1, 0, __LITTLE_ENDIAN, 10),
-				false, false, false),
+				false, false),
 	[ilog2(POLLOUT)] = lttng_kernel_static_event_field("POLLOUT",
 				lttng_kernel_static_type_integer(1, 1, 0, __LITTLE_ENDIAN, 10),
-				false, false, false),
+				false, false),
 	[ilog2(POLLERR)] = lttng_kernel_static_event_field("POLLERR",
 				lttng_kernel_static_type_integer(1, 1, 0, __LITTLE_ENDIAN, 10),
-				false, false, false),
+				false, false),
 	[ilog2(POLLHUP)] = lttng_kernel_static_event_field("POLLHUP",
 				lttng_kernel_static_type_integer(1, 1, 0, __LITTLE_ENDIAN, 10),
-				false, false, false),
+				false, false),
 	[ilog2(POLLNVAL)] = lttng_kernel_static_event_field("POLLNVAL",
 				lttng_kernel_static_type_integer(1, 1, 0, __LITTLE_ENDIAN, 10),
-				false, false, false),
+				false, false),
 	[ilog2(LTTNG_POLL_NRFLAGS)] = lttng_kernel_static_event_field("padding",
 				lttng_kernel_static_type_integer(POLL_FLAGS_PADDING_SIZE, 1, 0, __LITTLE_ENDIAN, 10),
-				false, false, false),
+				false, false),
 };
 
 static_assert(((ARRAY_SIZE(lttng_pollfd_flag_fields) - 1) + POLL_FLAGS_PADDING_SIZE) == sizeof(uint8_t) * BITS_PER_BYTE);
@@ -510,12 +510,12 @@ LTTNG_TRACEPOINT_TYPE(PARAMS(const struct lttng_kernel_type_struct lttng_pollfd_
 #ifndef LTTNG_TRACEPOINT_TYPE_EXTERN
 static const struct lttng_kernel_event_field *lttng_pollfd_fields[] = {
 	[0] = lttng_kernel_static_event_field("fd", lttng_kernel_static_type_integer_from_type(int, __BYTE_ORDER, 10),
-				false, false, false),
+				false, false),
 	[1] = lttng_kernel_static_event_field("raw_events", lttng_kernel_static_type_integer_from_type(uint16_t, __BYTE_ORDER, 16),
-				false, false, false),
+				false, false),
 	[2] = lttng_kernel_static_event_field("events",
 		(const struct lttng_kernel_type_common *) &lttng_pollfd_flag_fields_struct,
-		false, false, false),
+		false, false),
 };
 #endif /* LTTNG_TRACEPOINT_TYPE_EXTERN */
 
@@ -734,26 +734,26 @@ static const struct lttng_kernel_event_field *lttng_epoll_ctl_events_fields[] =
 	/* 0x0001 */
 	[ilog2(POLLIN)] = lttng_kernel_static_event_field("EPOLLIN",
 			lttng_kernel_static_type_integer(1, 1, 0, __LITTLE_ENDIAN, 10),
-			false, false, false),
+			false, false),
 	/* 0x0002 */
 	[ilog2(POLLPRI)] = lttng_kernel_static_event_field("EPOLLPRI",
 			lttng_kernel_static_type_integer(1, 1, 0, __LITTLE_ENDIAN, 10),
-			false, false, false),
+			false, false),
 	/* 0x0004 */
 	[ilog2(POLLOUT)] = lttng_kernel_static_event_field("EPOLLOUT",
 			lttng_kernel_static_type_integer(1, 1, 0, __LITTLE_ENDIAN, 10),
-			false, false, false),
+			false, false),
 	/* 0x0008 */
 	[ilog2(POLLERR)] = lttng_kernel_static_event_field("EPOLLERR",
 			lttng_kernel_static_type_integer(1, 1, 0, __LITTLE_ENDIAN, 10),
-			false, false, false),
+			false, false),
 	/* 0x0010 */
 	[ilog2(POLLHUP)] = lttng_kernel_static_event_field("EPOLLHUP",
 			lttng_kernel_static_type_integer(1, 1, 0, __LITTLE_ENDIAN, 10),
-			false, false, false),
+			false, false),
 	[ilog2(LTTNG_EPOLL_NRFLAGS)] = lttng_kernel_static_event_field("padding",
 			lttng_kernel_static_type_integer(EPOLL_FLAGS_PADDING_SIZE, 1, 0, __LITTLE_ENDIAN, 10),
-			false, false, false),
+			false, false),
 };
 #endif /* LTTNG_TRACEPOINT_TYPE_EXTERN */
 
@@ -764,10 +764,10 @@ LTTNG_TRACEPOINT_TYPE(PARAMS(const struct lttng_kernel_type_struct lttng_epoll_c
 static const struct lttng_kernel_event_field *lttng_epoll_data_fields[] = {
 	[0] = lttng_kernel_static_event_field("u64",
 			lttng_kernel_static_type_integer_from_type(uint64_t, __BYTE_ORDER, 16),
-			false, false, false),
+			false, false),
 	[1] = lttng_kernel_static_event_field("fd",
 			lttng_kernel_static_type_integer_from_type(int, __BYTE_ORDER, 10),
-			false, false, false),
+			false, false),
 };
 #endif /* LTTNG_TRACEPOINT_TYPE_EXTERN */
 
@@ -778,13 +778,13 @@ LTTNG_TRACEPOINT_TYPE(PARAMS(const struct lttng_kernel_type_struct lttng_epoll_d
 static const struct lttng_kernel_event_field *epoll_ctl_fields[] = {
 	[0] = lttng_kernel_static_event_field("data_union",
 		(const struct lttng_kernel_type_common *) &lttng_epoll_data_fields_struct,
-		false, false, false),
+		false, false),
 	[1] = lttng_kernel_static_event_field("raw_events",
 		lttng_kernel_static_type_integer_from_type(uint32_t, __BYTE_ORDER, 16),
-		false, false, false),
+		false, false),
 	[2] = lttng_kernel_static_event_field("events",
 		(const struct lttng_kernel_type_common *) &lttng_epoll_ctl_events_fields_struct,
-		false, false, false),
+		false, false),
 };
 #endif /* LTTNG_TRACEPOINT_TYPE_EXTERN */
 
@@ -851,12 +851,12 @@ SC_LTTNG_TRACEPOINT_EVENT_CODE(epoll_ctl,
 static const struct lttng_kernel_event_field *lttng_epoll_wait_fields[] = lttng_kernel_static_event_field_array(
 	[0] = lttng_kernel_static_event_field("data_union",
 			(const struct lttng_kernel_type_common *) &lttng_epoll_data_fields_struct,
-			false, false, false),
+			false, false),
 	[1] = lttng_kernel_static_event_field("raw_events", lttng_kernel_static_type_integer_from_type(uint32_t, __BYTE_ORDER, 16),
-			false, false, false),
+			false, false),
 	[2] = lttng_kernel_static_event_field("events",
 			(const struct lttng_kernel_type_common *) &lttng_epoll_ctl_events_fields_struct,
-			false, false, false),
+			false, false),
 );
 
 static_assert(((ARRAY_SIZE(lttng_epoll_ctl_events_fields) - 1) + EPOLL_FLAGS_PADDING_SIZE) == sizeof(uint8_t) * BITS_PER_BYTE);
